==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/openshift/api/model/ClusterRoleScopeRestrictionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class ClusterRoleScopeRestrictionBuilder extends ClusterRoleScopeRestrictionFluentImpl<ClusterRoleScopeRestrictionBuilder> implements VisitableBuilder<ClusterRoleScopeRestriction,ClusterRoleScopeRestrictionBuilder>{

    ClusterRoleScopeRestrictionFluent<?> fluent;
    Boolean validationEnabled;

    public ClusterRoleScopeRestrictionBuilder(){
            this(true);
    }
    public ClusterRoleScopeRestrictionBuilder(Boolean validationEnabled){
            this(new ClusterRoleScopeRestriction(), validationEnabled);
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestrictionFluent<?> fluent){
            this(fluent, true);
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestrictionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ClusterRoleScopeRestriction(), validationEnabled);
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestrictionFluent<?> fluent,ClusterRoleScopeRestriction instance){
            this(fluent, instance, true);
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestrictionFluent<?> fluent,ClusterRoleScopeRestriction instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withAllowEscalation(instance.getAllowEscalation()); 
            fluent.withNamespaces(instance.getNamespaces()); 
            fluent.withRoleNames(instance.getRoleNames()); 
            this.validationEnabled = validationEnabled; 
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestriction instance){
            this(instance,true);
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestriction instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withAllowEscalation(instance.getAllowEscalation()); 
            this.withNamespaces(instance.getNamespaces()); 
            this.withRoleNames(instance.getRoleNames()); 
            this.validationEnabled = validationEnabled; 
    }

    public ClusterRoleScopeRestriction build(){
            ClusterRoleScopeRestriction buildable = new ClusterRoleScopeRestriction(fluent.isAllowEscalation(),fluent.getNamespaces(),fluent.getRoleNames());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ClusterRoleScopeRestrictionBuilder that = (ClusterRoleScopeRestrictionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-4.1.1-sources.jar: annotations/io/fabric8/openshift/api/model/ClusterRoleScopeRestrictionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
import javax.validation.Validator;

public class ClusterRoleScopeRestrictionBuilder extends ClusterRoleScopeRestrictionFluentImpl<ClusterRoleScopeRestrictionBuilder> implements VisitableBuilder<ClusterRoleScopeRestriction,ClusterRoleScopeRestrictionBuilder>{

    ClusterRoleScopeRestrictionFluent<?> fluent;
    Boolean validationEnabled;
    Validator validator;

    public ClusterRoleScopeRestrictionBuilder(){
            this(true);
    }
    public ClusterRoleScopeRestrictionBuilder(Boolean validationEnabled){
            this(new ClusterRoleScopeRestriction(), validationEnabled);
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestrictionFluent<?> fluent){
            this(fluent, true);
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestrictionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ClusterRoleScopeRestriction(), validationEnabled);
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestrictionFluent<?> fluent,ClusterRoleScopeRestriction instance){
            this(fluent, instance, true);
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestrictionFluent<?> fluent,ClusterRoleScopeRestriction instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withAllowEscalation(instance.getAllowEscalation()); 
            fluent.withNamespaces(instance.getNamespaces()); 
            fluent.withRoleNames(instance.getRoleNames()); 
            this.validationEnabled = validationEnabled; 
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestriction instance){
            this(instance,true);
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestriction instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withAllowEscalation(instance.getAllowEscalation()); 
            this.withNamespaces(instance.getNamespaces()); 
            this.withRoleNames(instance.getRoleNames()); 
            this.validationEnabled = validationEnabled; 
    }
    public ClusterRoleScopeRestrictionBuilder(Validator validator){
            this(new ClusterRoleScopeRestriction(), true);
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestrictionFluent<?> fluent,ClusterRoleScopeRestriction instance,Validator validator){
            this.fluent = fluent; 
            fluent.withAllowEscalation(instance.getAllowEscalation()); 
            fluent.withNamespaces(instance.getNamespaces()); 
            fluent.withRoleNames(instance.getRoleNames()); 
            this.validator = validator;
            this.validationEnabled = validator != null; 
    }
    public ClusterRoleScopeRestrictionBuilder(ClusterRoleScopeRestriction instance,Validator validator){
            this.fluent = this; 
            this.withAllowEscalation(instance.getAllowEscalation()); 
            this.withNamespaces(instance.getNamespaces()); 
            this.withRoleNames(instance.getRoleNames()); 
            this.validator = validator; 
            this.validationEnabled = validator != null; 
    }

    public ClusterRoleScopeRestriction build(){
            ClusterRoleScopeRestriction buildable = new ClusterRoleScopeRestriction(fluent.isAllowEscalation(),fluent.getNamespaces(),fluent.getRoleNames());
            if (validationEnabled) {io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable, validator);}
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ClusterRoleScopeRestrictionBuilder that = (ClusterRoleScopeRestrictionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
